{$I DacDemo.inc}

unit Table;

interface

uses
{$IFDEF MSWINDOWS}
  Windows, Messages,
{$ENDIF}
{$IFNDEF KYLIX}
  SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Grids, DBGrids, StdCtrls, ToolWin, ComCtrls, Buttons,
  OdacVcl,
{$ELSE}
  SysUtils, Types, Classes, QGraphics, QControls, QForms, QDialogs, QStdCtrls,
  QDBCtrls, QComCtrls, QExtCtrls, QGrids, QDBGrids, QButtons, OdacClx,
{$ENDIF}
{$IFDEF FPC}
  LResources,
{$ENDIF}
  Db, {$IFNDEF FPC}MemDS{$ELSE}MemDataSet{$ENDIF},
  DBAccess, Ora, OraSmart, OdacDemoFrame, OdacDemoForm;

type
  TTableFrame = class(TOdacDemoFrame)
    DBGrid: TDBGrid;
    DataSource: TDataSource;
    ToolBar: TPanel;
    Panel3: TPanel;
    btOpen: TSpeedButton;
    btClose: TSpeedButton;
    btPrepare: TSpeedButton;
    btUnPrepare: TSpeedButton;
    btExecute: TSpeedButton;
    DBNavigator: TDBNavigator;
    OraTable: TOraTable;
    Panel7: TPanel;
    Label3: TLabel;
    edOrderFields: TEdit;
    Panel8: TPanel;
    Label4: TLabel;
    edFilterSQL: TEdit;
    Panel6: TPanel;
    Label5: TLabel;
    edKeyFields: TEdit;
    Panel5: TPanel;
    Label1: TLabel;
    edTableName: TEdit;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btPrepareClick(Sender: TObject);
    procedure btUnPrepareClick(Sender: TObject);
    procedure btExecuteClick(Sender: TObject);
    procedure edTableNameExit(Sender: TObject);
    procedure edKeyFieldsExit(Sender: TObject);
    procedure edOrderFieldsExit(Sender: TObject);
    procedure edFilterSQLExit(Sender: TObject);
  private
    { Private declarations }
    procedure ShowState;
    procedure SetTableProperties;
  public
    procedure Initialize; override;
    procedure SetDebug(Value: boolean); override;
  end;

implementation

{$IFNDEF FPC}
{$IFDEF CLR}
{$R *.nfm}
{$ELSE}
{$R *.dfm}
{$ENDIF}
{$ENDIF}

procedure TTableFrame.ShowState;
var
  St:string;

  procedure AddSt(S:string);
  begin
    if St <> '' then
      St := St + ', ';
    St := St + S;
  end;

begin
  St := '';

  if OraTable.Prepared then begin
    AddSt('Prepared');

    if OraTable.IsQuery then
      AddSt('IsQuery');

    if OraTable.IsPLSQL then
      AddSt('IsPLSQL');
  end;

  if OraTable.Active then
    AddSt('Active')
  else
    AddSt('Inactive');

  OdacForm.StatusBar.Panels[0].Text := St;
end;

procedure TTableFrame.SetTableProperties;
begin
  OraTable.TableName := edTableName.Text;
  OraTable.KeyFields := edKeyFields.Text;
  OraTable.FilterSQL := edFilterSQL.Text;
  OraTable.OrderFields := edOrderFields.Text;
end;

procedure TTableFrame.btOpenClick(Sender: TObject);
begin
  try
    SetTableProperties;
    OraTable.Open;
  finally
    edKeyFields.Text := OraTable.KeyFields;
    ShowState;
  end;
end;

procedure TTableFrame.btCloseClick(Sender: TObject);
begin
  OraTable.Close;
  ShowState;
end;

procedure TTableFrame.btPrepareClick(Sender: TObject);
begin
  try
    SetTableProperties;
    OraTable.Prepare;
  finally
    edKeyFields.Text := OraTable.KeyFields;
    ShowState;
  end;
end;

procedure TTableFrame.btUnPrepareClick(Sender: TObject);
begin
  OraTable.UnPrepare;
  ShowState;
end;

procedure TTableFrame.btExecuteClick(Sender: TObject);
begin
  try
    SetTableProperties;
    OraTable.Execute;
  finally
    edKeyFields.Text := OraTable.KeyFields;
    ShowState;
  end;
end;

procedure TTableFrame.Initialize;
begin
  inherited;

  OraTable.Connection := Connection;

  edTableName.Text := OraTable.TableName;
  edKeyFields.Text := OraTable.KeyFields;
  edOrderFields.Text := OraTable.OrderFields;
  edFilterSQL.Text := OraTable.FilterSQL;
  ShowState;
end;

procedure TTableFrame.edTableNameExit(Sender: TObject);
begin
  OraTable.TableName := edTableName.Text;
  edKeyFields.Text := OraTable.KeyFields;
  ShowState;
end;

procedure TTableFrame.edKeyFieldsExit(Sender: TObject);
begin
  OraTable.KeyFields := edKeyFields.Text;
  ShowState;
end;

procedure TTableFrame.edOrderFieldsExit(Sender: TObject);
begin
  OraTable.OrderFields := edOrderFields.Text;
  edKeyFields.Text := OraTable.KeyFields;
  ShowState;
end;

procedure TTableFrame.SetDebug(Value: boolean);
begin
  OraTable.Debug := Value;
end;

procedure TTableFrame.edFilterSQLExit(Sender: TObject);
begin
  try
    OraTable.FilterSQL := edFilterSQL.Text;
  finally
    edFilterSQL.Text := OraTable.FilterSQL;
    ShowState;
  end;
end;

initialization
{$IFDEF FPC}
{$I Table.lrs}
{$ENDIF}

end.
